@@ -31,8 +31,8 @@ extern struct __res_state _res;
 static char def_payload[] = "\0\0\0\0\0\0\0\0\0\0"; /* default payload for UDP packets */
 #endif
 
-const char *version = "3.91";  		/* set version string */
-static const char *version_date = "(04/2020)";	/* date of this version */
+const char *version = "3.93";  		/* set version string */
+static const char *version_date = "(09/2025)";	/* date of this version */
 
 static void
 usage(lft_session_params * sess, char *prog)
@@ -98,7 +98,7 @@ show_version (void)
     fprintf (stderr, "\n"
              "Layer Four Traceroute (LFT) - version %s %s\n\n    - the alternative traceroute tool for network [reverse] engineers\n\n"
              "    Compile-time options:\n\n"
-#if defined(DARWIN)
+#if defined(DARWIN) || defined(__APPLE__)
              "      + Darwin (or MacOS)\n"
 #endif
 #if defined(UNIVERSAL)
