@@ -4,9 +4,6 @@
 
 static LFT_CALLBACK LFTErrHandler=0;
 static LFT_CALLBACK LFTEvtHandler=0;
-extern const char *version;
-extern const char *appname;
-extern const int maxpacklen;
 
 static int getFreePort(lft_session_params * sess, int startfrom)
 {
