@@ -39,6 +39,12 @@ u_long
 lft_getifaddr (const char *ifname)
 {
 	struct ifreq ifr;
+	struct sockaddr_in addr;
+    
+    if(!ifname){
+		perror ("The user-supplied network interface is not suitable");
+		return -1;
+    }
 
 	/* Only do this once of course */
 	if (sock < 0) {
@@ -55,7 +61,15 @@ lft_getifaddr (const char *ifname)
 		return -1;
 	}
 
-	return ((struct sockaddr_in *)(&(ifr.ifr_addr)))->sin_addr.s_addr;
+	if (ifr.ifr_addr.sa_family != AF_INET) {
+		fprintf (stderr, "%s: Interface not configured with IPv4 address.\n", ifname);
+		fflush (stderr);
+		return -1;
+	}
+
+	memcpy(&addr, &ifr.ifr_addr, sizeof addr);
+
+	return (addr.sin_addr.s_addr);
 }
 
 char *
@@ -96,7 +110,7 @@ lft_getifname (struct in_addr addr)
 
 		if (ifr.ifr_addr.sa_family != AF_INET) continue;
 
-		thisaddr = ((struct sockaddr_in *)&ifr.ifr_addr)->sin_addr;
+		thisaddr = ((const struct sockaddr_in *)(const void *)(&(ifr.ifr_addr)))->sin_addr;
 
 		if (thisaddr.s_addr == addr.s_addr)
 		  return strdup(ifr.ifr_name);
