@@ -119,7 +119,8 @@ struct name {								\
 
 #define SLIST_HEAD_INITIALIZER(head)					\
 	{ NULL }
- 
+
+#undef SLIST_ENTRY
 #define SLIST_ENTRY(type)						\
 struct {								\
 	struct type *sle_next;	/* next element */			\
@@ -197,11 +198,13 @@ struct {								\
 
 #define STAILQ_FIRST(head)	((head)->stqh_first)
 
+#ifndef STAILQ_LAST
 #define	STAILQ_LAST(head, type, field)					\
 	(STAILQ_EMPTY(head) ?						\
 		NULL :							\
 	        ((struct type *)					\
 		((char *)((head)->stqh_last) - __offsetof(struct type, field))))
+#endif
 
 #define STAILQ_FOREACH(var, head, field)				\
 	for((var) = (head)->stqh_first; (var); (var) = (var)->field.stqe_next)
@@ -340,10 +343,12 @@ struct {								\
 #define TAILQ_FOREACH(var, head, field)					\
 	for (var = TAILQ_FIRST(head); var; var = TAILQ_NEXT(var, field))
 
+#ifndef TAILQ_FOREACH_REVERSE
 #define TAILQ_FOREACH_REVERSE(var, head, headname, field)		\
 	for ((var) = TAILQ_LAST((head), headname);			\
 	     (var);							\
 	     (var) = TAILQ_PREV((var), headname, field))
+#endif
 
 #define	TAILQ_FIRST(head) ((head)->tqh_first)
 
