@@ -120,7 +120,11 @@ typedef signed long n_time;
 #include "lft_lsrr.h"
 #include "whois.h"
 
-#if defined(__FreeBSD__)
+#if defined(__OpenBSD__)
+#include <stdint.h>
+#endif
+
+#if defined(__FreeBSD__) || defined(DARWIN) || defined(__APPLE__)
 #include <sys/queue.h>
 #elif !defined(DARWIN) && !defined(NETBSD)
 #include "lft_queue.h"
